summaryrefslogtreecommitdiffstats
path: root/kdict
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
commit83677e35509b4dafac63b76995652bdf3b49f209 (patch)
tree591f1dc22278addb439726c42896376b17bb42bd /kdict
parent808e453c56036211f57482ed847d54aca01bba68 (diff)
downloadtdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.tar.gz
tdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 808e453c56036211f57482ed847d54aca01bba68.
Diffstat (limited to 'kdict')
-rw-r--r--kdict/actions.cpp10
-rw-r--r--kdict/applet/kdictapplet.cpp14
-rw-r--r--kdict/dict.cpp24
-rw-r--r--kdict/matchview.cpp34
-rw-r--r--kdict/matchview.h2
-rw-r--r--kdict/options.cpp10
-rw-r--r--kdict/options.h2
-rw-r--r--kdict/queryview.cpp36
-rw-r--r--kdict/sets.cpp22
-rw-r--r--kdict/toplevel.cpp38
10 files changed, 96 insertions, 96 deletions
diff --git a/kdict/actions.cpp b/kdict/actions.cpp
index 1c9c757c..5f5480aa 100644
--- a/kdict/actions.cpp
+++ b/kdict/actions.cpp
@@ -46,7 +46,7 @@ int DictComboAction::plug( TQWidget *widget, int index )
m_combo = new KComboBox(m_editable,bar);
m_combo->setCompletionMode(m_compMode);
- bar->insertWidget( id_, m_combo->sizeHint().width(), m_combo, index );
+ bar->insertWidget( id_, m_combo->tqsizeHint().width(), m_combo, index );
bar->setItemAutoSized(id_,m_autoSized);
if ( m_combo ) {
@@ -155,7 +155,7 @@ void DictComboAction::setList(TQStringList items)
if (m_editable && m_combo->completionObject())
m_combo->completionObject()->setItems(items);
if (!m_autoSized)
- m_combo->setFixedWidth(m_combo->sizeHint().width());
+ m_combo->setFixedWidth(m_combo->tqsizeHint().width());
}
}
@@ -213,9 +213,9 @@ int DictLabelAction::plug( TQWidget *widget, int index )
int id = KAction::getToolButtonID();
TQLabel *label = new TQLabel( text(), widget, "kde toolbar widget" );
- label->setMinimumWidth(label->sizeHint().width());
+ label->setMinimumWidth(label->tqsizeHint().width());
label->setBackgroundMode( TQt::PaletteButton );
- label->setAlignment(AlignCenter | AlignVCenter);
+ label->tqsetAlignment(AlignCenter | AlignVCenter);
label->adjustSize();
tb->insertWidget( id, label->width(), label, index );
@@ -320,7 +320,7 @@ void DictButtonAction::unplug( TQWidget *widget )
int DictButtonAction::widthHint()
{
if (m_button)
- return m_button->sizeHint().width();
+ return m_button->tqsizeHint().width();
else
return 0;
}
diff --git a/kdict/applet/kdictapplet.cpp b/kdict/applet/kdictapplet.cpp
index 706e7e9a..0179f0b8 100644
--- a/kdict/applet/kdictapplet.cpp
+++ b/kdict/applet/kdictapplet.cpp
@@ -20,7 +20,7 @@
#include <tqlabel.h>
#include <tqpushbutton.h>
#include <tqtimer.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqtooltip.h>
#include <kconfig.h>
@@ -102,7 +102,7 @@ DictApplet::DictApplet(const TQString& configFile, Type type, int actions, TQWid
TQPixmap pm = KGlobal::iconLoader()->loadIcon("kdict", KIcon::Panel, KIcon::SizeSmall, KIcon::DefaultState, 0L, true);
iconLabel->setPixmap(pm);
baseLay->addWidget(iconLabel,1,0);
- iconLabel->setAlignment(TQt::AlignCenter | TQt::AlignVCenter);
+ iconLabel->tqsetAlignment(TQt::AlignCenter | TQt::AlignVCenter);
iconLabel->setFixedWidth(pm.width()+4);
TQToolTip::add(iconLabel,i18n("Look up a word or phrase with Kdict"));
@@ -160,7 +160,7 @@ DictApplet::DictApplet(const TQString& configFile, Type type, int actions, TQWid
externalCombo = new KHistoryCombo(popupBox);
externalCombo->setCompletionObject(completionObject);
connect(externalCombo, TQT_SIGNAL(returnPressed(const TQString&)), TQT_SLOT(startQuery(const TQString&)));
- externalCombo->setFixedSize(160, externalCombo->sizeHint().height());
+ externalCombo->setFixedSize(160, externalCombo->tqsizeHint().height());
connect(internalCombo, TQT_SIGNAL(completionModeChanged(KGlobalSettings::Completion)),
this, TQT_SLOT(updateCompletionMode(KGlobalSettings::Completion)));
@@ -205,9 +205,9 @@ DictApplet::~DictApplet()
int DictApplet::widthForHeight(int height) const
{
if (height >= 38)
- return textLabel->sizeHint().width()+55;
+ return textLabel->tqsizeHint().width()+55;
else
- return textLabel->sizeHint().width()+25;
+ return textLabel->tqsizeHint().width()+25;
}
@@ -224,10 +224,10 @@ void DictApplet::resizeEvent(TQResizeEvent*)
baseWidget->show();
baseWidget->setFixedSize(width(),height());
- if (height() < internalCombo->sizeHint().height())
+ if (height() < internalCombo->tqsizeHint().height())
internalCombo->setFixedHeight(height());
else
- internalCombo->setFixedHeight(internalCombo->sizeHint().height());
+ internalCombo->setFixedHeight(internalCombo->tqsizeHint().height());
if (height() >= 38) {
textLabel->show();
diff --git a/kdict/dict.cpp b/kdict/dict.cpp
index 8da41eee..8e55061c 100644
--- a/kdict/dict.cpp
+++ b/kdict/dict.cpp
@@ -23,7 +23,7 @@
#include "dict.h"
#include <tqregexp.h>
-#include <textcodec.h>
+#include <tqtextcodec.h>
#include <klocale.h>
#include <kdebug.h>
@@ -204,12 +204,12 @@ void DictAsyncClient::define()
job->result = TQString();
if (job->numFetched == 0) {
resultAppend("<body>\n<p class=\"heading\">\n");
- resultAppend(i18n("No definitions found for \'%1'.").arg(job->query));
+ resultAppend(i18n("No definitions found for \'%1'.").tqarg(job->query));
resultAppend("</p>\n</html></body>");
} else {
// html header...
resultAppend("<body>\n<p class=\"heading\">\n");
- resultAppend(i18n("No definitions found for \'%1\'. Perhaps you mean:").arg(job->query));
+ resultAppend(i18n("No definitions found for \'%1\'. Perhaps you mean:").tqarg(job->query));
resultAppend("</p>\n<table width=\"100%\" cols=2>\n");
TQString lastDb;
@@ -591,7 +591,7 @@ void DictAsyncClient::showDbInfo()
// html header...
resultAppend("<body>\n<p class=\"heading\">\n");
- resultAppend(i18n("Database Information [%1]:").arg(job->query));
+ resultAppend(i18n("Database Information [%1]:").tqarg(job->query));
resultAppend("</p>\n<pre><p class=\"definition\">\n");
bool done(false);
@@ -1407,7 +1407,7 @@ void DictInterface::clientDone()
message = i18n("One definition found");
break;
default:
- message = i18n("%1 definitions found").arg(job->numFetched);
+ message = i18n("%1 definitions found").tqarg(job->numFetched);
}
} else {
switch (job->numFetched) {
@@ -1418,7 +1418,7 @@ void DictInterface::clientDone()
message = i18n(" One definition fetched ");
break;
default:
- message = i18n(" %1 definitions fetched ").arg(job->numFetched);
+ message = i18n(" %1 definitions fetched ").tqarg(job->numFetched);
}
}
emit stopped(message);
@@ -1433,7 +1433,7 @@ void DictInterface::clientDone()
message = i18n(" One matching definition found ");
break;
default:
- message = i18n(" %1 matching definitions found ").arg(job->numFetched);
+ message = i18n(" %1 matching definitions found ").tqarg(job->numFetched);
}
emit stopped(message);
emit matchReady(job->matches);
@@ -1451,17 +1451,17 @@ void DictInterface::clientDone()
errMsg += job->result;
break;
case JobData::ErrTimeout:
- errMsg = i18n("A delay occurred which exceeded the\ncurrent timeout limit of %1 seconds.\nYou can modify this limit in the Preferences Dialog.").arg(global->timeout);
+ errMsg = i18n("A delay occurred which exceeded the\ncurrent timeout limit of %1 seconds.\nYou can modify this limit in the Preferences Dialog.").tqarg(global->timeout);
break;
case JobData::ErrBadHost:
- errMsg = i18n("Unable to connect to:\n%1:%2\n\nCannot resolve hostname.").arg(job->server).arg(job->port);
+ errMsg = i18n("Unable to connect to:\n%1:%2\n\nCannot resolve hostname.").tqarg(job->server).tqarg(job->port);
break;
case JobData::ErrConnect:
- errMsg = i18n("Unable to connect to:\n%1:%2\n\n").arg(job->server).arg(job->port);
+ errMsg = i18n("Unable to connect to:\n%1:%2\n\n").tqarg(job->server).tqarg(job->port);
errMsg += job->result;
break;
case JobData::ErrRefused:
- errMsg = i18n("Unable to connect to:\n%1:%2\n\nThe server refused the connection.").arg(job->server).arg(job->port);
+ errMsg = i18n("Unable to connect to:\n%1:%2\n\nThe server refused the connection.").tqarg(job->server).tqarg(job->port);
break;
case JobData::ErrNotAvailable:
errMsg = i18n("The server is temporarily unavailable.");
@@ -1488,7 +1488,7 @@ void DictInterface::clientDone()
errMsg = i18n("No strategies available.");
break;
case JobData::ErrServerError:
- errMsg = i18n("The server sent an unexpected reply:\n\"%1\"\nThis shouldn't happen, please consider\nwriting a bug report").arg(job->result);
+ errMsg = i18n("The server sent an unexpected reply:\n\"%1\"\nThis shouldn't happen, please consider\nwriting a bug report").tqarg(job->result);
break;
case JobData::ErrMsgTooLong:
errMsg = i18n("The server sent a response with a text line\nthat was too long.\n(RFC 2229: max. 1024 characters/6144 octets)");
diff --git a/kdict/matchview.cpp b/kdict/matchview.cpp
index 9243615e..e4dd030b 100644
--- a/kdict/matchview.cpp
+++ b/kdict/matchview.cpp
@@ -13,11 +13,11 @@
------------------------------------------------------------- */
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <tqcombobox.h>
#include <tqpushbutton.h>
#include <tqheader.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqpainter.h>
#include <tqregexp.h>
@@ -96,14 +96,14 @@ void MatchViewItem::setOpen(bool o)
}
-void MatchViewItem::paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int alignment)
+void MatchViewItem::paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int tqalignment)
{
if(command.isEmpty()) {
TQFont font=p->font();
font.setBold(true);
p->setFont(font);
}
- TQListViewItem::paintCell(p,cg,column,width,alignment);
+ TQListViewItem::paintCell(p,cg,column,width,tqalignment);
}
@@ -119,7 +119,7 @@ MatchView::MatchView(TQWidget *parent, const char *name)
boxLayout->addSpacing(1);
w_strat = new TQComboBox(false,this);
- w_strat->setFixedHeight(w_strat->sizeHint().height());
+ w_strat->setFixedHeight(w_strat->tqsizeHint().height());
connect(w_strat,TQT_SIGNAL(activated(int)),this,TQT_SLOT(strategySelected(int)));
boxLayout->addWidget(w_strat,0);
boxLayout->addSpacing(1);
@@ -133,7 +133,7 @@ MatchView::MatchView(TQWidget *parent, const char *name)
w_list->setSelectionMode(TQListView::Extended);
w_list->setTreeStepSize(18);
w_list->setSorting(-1); // disable sorting
- w_list->setMinimumHeight(w_strat->sizeHint().height());
+ w_list->setMinimumHeight(w_strat->tqsizeHint().height());
connect(w_list,TQT_SIGNAL(selectionChanged()),TQT_SLOT(enableGetButton()));
connect(w_list,TQT_SIGNAL(returnPressed(TQListViewItem *)),TQT_SLOT(returnPressed(TQListViewItem *)));
connect(w_list,TQT_SIGNAL(doubleClicked(TQListViewItem *)),TQT_SLOT(getOneItem(TQListViewItem *)));
@@ -144,15 +144,15 @@ MatchView::MatchView(TQWidget *parent, const char *name)
boxLayout->addSpacing(1);
w_get = new TQPushButton(i18n("&Get Selected"),this);
- w_get->setFixedHeight(w_get->sizeHint().height()-3);
- w_get->setMinimumWidth(w_get->sizeHint().width()-20);
+ w_get->setFixedHeight(w_get->tqsizeHint().height()-3);
+ w_get->setMinimumWidth(w_get->tqsizeHint().width()-20);
w_get->setEnabled(false);
connect(w_get, TQT_SIGNAL(clicked()), this, TQT_SLOT(getSelected()));
boxLayout->addWidget(w_get,0);
w_getAll = new TQPushButton(i18n("Get &All"),this);
- w_getAll->setFixedHeight(w_getAll->sizeHint().height()-3);
- w_getAll->setMinimumWidth(w_getAll->sizeHint().width()-20);
+ w_getAll->setFixedHeight(w_getAll->tqsizeHint().height()-3);
+ w_getAll->setMinimumWidth(w_getAll->tqsizeHint().width()-20);
w_getAll->setEnabled(false);
connect(w_getAll, TQT_SIGNAL(clicked()), this, TQT_SLOT(getAll()));
boxLayout->addWidget(w_getAll,0);
@@ -310,7 +310,7 @@ void MatchView::doGet(TQStringList &defines)
if (defines.count() > 0) {
if (defines.count() > global->maxDefinitions) {
KMessageBox::sorry(global->topLevel,i18n("You have selected %1 definitions,\nbut Kdict will fetch only the first %2 definitions.\nYou can modify this limit in the Preferences Dialog.")
- .arg(defines.count()).arg(global->maxDefinitions));
+ .tqarg(defines.count()).tqarg(global->maxDefinitions));
while (defines.count()>global->maxDefinitions)
defines.pop_back();
}
@@ -368,7 +368,7 @@ void MatchView::newList(const TQStringList &matches)
}
w_list->setUpdatesEnabled(true);
- w_list->repaint();
+ w_list->tqrepaint();
w_list->setFocus();
}
@@ -388,14 +388,14 @@ void MatchView::buildPopupMenu(TQListViewItem *i, const TQPoint &_point, int)
rightBtnMenu->insertSeparator();
}
- kapp->clipboard()->setSelectionMode(false);
- TQString text = kapp->clipboard()->text();
+ kapp->tqclipboard()->setSelectionMode(false);
+ TQString text = kapp->tqclipboard()->text();
if (text.isEmpty()) {
- kapp->clipboard()->setSelectionMode(true);
- text = kapp->clipboard()->text();
+ kapp->tqclipboard()->setSelectionMode(true);
+ text = kapp->tqclipboard()->text();
}
if (!text.isEmpty()) {
- popupClip = kapp->clipboard()->text();
+ popupClip = kapp->tqclipboard()->text();
rightBtnMenu->insertItem(i18n("Match &Clipboard Content"),this,TQT_SLOT(popupMatchClip()));
rightBtnMenu->insertItem(SmallIcon("define_clip"),i18n("D&efine Clipboard Content"),this,TQT_SLOT(popupDefineClip()));
rightBtnMenu->insertSeparator();
diff --git a/kdict/matchview.h b/kdict/matchview.h
index 3e7e9f7e..5a459e34 100644
--- a/kdict/matchview.h
+++ b/kdict/matchview.h
@@ -35,7 +35,7 @@ public:
~MatchViewItem();
void setOpen(bool o);
- void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int alignment);
+ void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int tqalignment);
TQString command;
TQStringList subEntrys;
diff --git a/kdict/options.cpp b/kdict/options.cpp
index 5f307290..de10606d 100644
--- a/kdict/options.cpp
+++ b/kdict/options.cpp
@@ -20,7 +20,7 @@
#include <tqcheckbox.h>
#include <tqpushbutton.h>
#include <tqradiobutton.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqcombobox.h>
#include <tqbuttongroup.h>
@@ -104,7 +104,7 @@ void GlobalData::read()
f_onts[Fheadings]=config->readFontEntry("headingsFont",&defFont);
f_ontNames[Fheadings]=i18n("Headings");
- // geometry...
+ // tqgeometry...
config->setGroup("Geometry");
TQSize invalid(-1,-1);
optSize = config->readSizeEntry("Opt_Size",&invalid);
@@ -449,7 +449,7 @@ int OptionsDialog::ColorListItem::width(const TQListBox *lb ) const
OptionsDialog::FontListItem::FontListItem( const TQString &name, const TQFont &font )
: TQListBoxText(name), f_ont(font)
{
- fontInfo = TQString("[%1 %2]").arg(f_ont.family()).arg(f_ont.pointSize());
+ fontInfo = TQString("[%1 %2]").tqarg(f_ont.family()).tqarg(f_ont.pointSize());
}
@@ -461,7 +461,7 @@ OptionsDialog::FontListItem::~FontListItem()
void OptionsDialog::FontListItem::setFont(const TQFont &font)
{
f_ont = font;
- fontInfo = TQString("[%1 %2]").arg(f_ont.family()).arg(f_ont.pointSize());
+ fontInfo = TQString("[%1 %2]").tqarg(f_ont.family()).tqarg(f_ont.pointSize());
}
@@ -869,7 +869,7 @@ void OptionsDialog::slotColDefaultBtnClicked()
colorItem->setColor(global->defaultColor(i));
}
c_List->triggerUpdate(true);
- c_List->repaint(true);
+ c_List->tqrepaint(true);
}
diff --git a/kdict/options.h b/kdict/options.h
index 1137caf8..a1b2745e 100644
--- a/kdict/options.h
+++ b/kdict/options.h
@@ -74,7 +74,7 @@ public:
bool defineClipboard; // define clipboard content on startup?
- TQSize optSize,setsSize,matchSize; // window geometry
+ TQSize optSize,setsSize,matchSize; // window tqgeometry
bool showMatchList;
TQValueList<int> splitterSizes;
diff --git a/kdict/queryview.cpp b/kdict/queryview.cpp
index eb0cf7f5..3b0cf9e3 100644
--- a/kdict/queryview.cpp
+++ b/kdict/queryview.cpp
@@ -15,7 +15,7 @@
------------------------------------------------------------- */
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <tqtimer.h>
#include <kfiledialog.h>
@@ -74,7 +74,7 @@ TQFile* SaveHelper::getFile(const TQString &dialogTitle)
if (url.isLocalFile()) {
if (TQFileInfo(url.path()).exists() &&
(KMessageBox::warningContinueCancel(global->topLevel,
- i18n("A file named %1 already exists.\nDo you want to replace it?").arg(url.path()),
+ i18n("A file named %1 already exists.\nDo you want to replace it?").tqarg(url.path()),
dialogTitle, i18n("&Replace")) != KMessageBox::Continue)) {
return 0;
}
@@ -184,11 +184,11 @@ void QueryView::optionsChanged()
saveCurrentResultPos();
currentHTMLHeader = TQString("<html><head><style type=\"text/css\">\n");
- currentHTMLHeader += TQString("body { background-color:%1; color:%2; }\n").arg(global->backgroundColor().name()).arg(global->textColor().name());
- currentHTMLHeader += TQString("a:link, a:active { color:%1; text-decoration:none; }\n").arg(global->linksColor().name());
- currentHTMLHeader += TQString("a:visited { color:%1; text-decoration:none; }\n").arg(global->visitedLinksColor().name());
- currentHTMLHeader += TQString("a:hover { color:%1; text-decoration:underline; }\n").arg(global->linksColor().name());
- currentHTMLHeader += TQString("p.heading { margin-left:0mm; margin-top:2mm; margin-bottom:2mm; padding:1mm; background-color:%1; color:%2; font-family:%3; font-size:%4pt; ").arg(global->headingsBackgroundColor().name()).arg(global->headingsTextColor().name()).arg(global->headingsFont().family()).arg(global->headingsFont().pointSize());
+ currentHTMLHeader += TQString("body { background-color:%1; color:%2; }\n").tqarg(global->backgroundColor().name()).tqarg(global->textColor().name());
+ currentHTMLHeader += TQString("a:link, a:active { color:%1; text-decoration:none; }\n").tqarg(global->linksColor().name());
+ currentHTMLHeader += TQString("a:visited { color:%1; text-decoration:none; }\n").tqarg(global->visitedLinksColor().name());
+ currentHTMLHeader += TQString("a:hover { color:%1; text-decoration:underline; }\n").tqarg(global->linksColor().name());
+ currentHTMLHeader += TQString("p.heading { margin-left:0mm; margin-top:2mm; margin-bottom:2mm; padding:1mm; background-color:%1; color:%2; font-family:%3; font-size:%4pt; ").tqarg(global->headingsBackgroundColor().name()).tqarg(global->headingsTextColor().name()).tqarg(global->headingsFont().family()).tqarg(global->headingsFont().pointSize());
if (global->headingsFont().italic())
currentHTMLHeader += TQString("font-style:italic; ");
if (global->headingsFont().bold())
@@ -196,7 +196,7 @@ void QueryView::optionsChanged()
currentHTMLHeader += TQString("}\n");
currentHTMLHeader += TQString("p.definition { margin-left:1.5mm; margin-top:2mm; margin-bottom:2mm;}\n");
currentHTMLHeader += TQString("table { margin-left:1.5mm; margin-top:2mm; margin-bottom:2mm;}\n");
- currentHTMLHeader += TQString("pre { font-family:%1; font-size:%2pt; ").arg(global->textFont().family()).arg(global->textFont().pointSize());
+ currentHTMLHeader += TQString("pre { font-family:%1; font-size:%2pt; ").tqarg(global->textFont().family()).tqarg(global->textFont().pointSize());
if (global->textFont().italic())
currentHTMLHeader += TQString("font-style:italic; ");
if (global->textFont().bold())
@@ -276,7 +276,7 @@ void QueryView::selectAll()
void QueryView::copySelection()
{
- kapp->clipboard()->setText(part->selectedText());
+ kapp->tqclipboard()->setText(part->selectedText());
}
@@ -441,14 +441,14 @@ void QueryView::buildPopupMenu(const TQString &url, const TQPoint &point)
this,TQT_SLOT(popupMatchSelect()));
rightBtnMenu->insertSeparator();
} else {
- kapp->clipboard()->setSelectionMode(false);
- TQString text = kapp->clipboard()->text();
+ kapp->tqclipboard()->setSelectionMode(false);
+ TQString text = kapp->tqclipboard()->text();
if (text.isEmpty()) {
- kapp->clipboard()->setSelectionMode(true);
- text = kapp->clipboard()->text();
+ kapp->tqclipboard()->setSelectionMode(true);
+ text = kapp->tqclipboard()->text();
}
if (!text.isEmpty()) {
- popupSelect = TQApplication::clipboard()->text();
+ popupSelect = TQApplication::tqclipboard()->text();
rightBtnMenu->insertItem(SmallIcon("define_clip"),
i18n("&Define Clipboard Content"),
this,TQT_SLOT(popupDefineSelect()));
@@ -467,7 +467,7 @@ void QueryView::buildPopupMenu(const TQString &url, const TQPoint &point)
this,TQT_SLOT(browseBack()));
else
rightBtnMenu->insertItem(SmallIcon("back"),
- i18n("&Back: '%1'").arg(getShortString(browseList.at(browsePos-1)->queryText,25)),
+ i18n("&Back: '%1'").tqarg(getShortString(browseList.at(browsePos-1)->queryText,25)),
this,TQT_SLOT(browseBack()));
} else {
ID = rightBtnMenu->insertItem(SmallIcon("back"), i18n("&Back"), this, TQT_SLOT(browseBack()));
@@ -481,7 +481,7 @@ void QueryView::buildPopupMenu(const TQString &url, const TQPoint &point)
this,TQT_SLOT(browseForward()));
else
rightBtnMenu->insertItem(SmallIcon("forward"),
- i18n("&Forward: '%1'").arg(getShortString(browseList.at(browsePos+1)->queryText,25)),
+ i18n("&Forward: '%1'").tqarg(getShortString(browseList.at(browsePos+1)->queryText,25)),
this,TQT_SLOT(browseForward()));
} else {
ID = rightBtnMenu->insertItem(SmallIcon("forward"),i18n("&Forward"),this,TQT_SLOT(browseForward()));
@@ -569,7 +569,7 @@ void QueryView::updateBrowseActions()
if (browseList.at(browsePos-1)->queryText.isEmpty())
actBack->setText(i18n("&Back: Information"));
else
- actBack->setText(i18n("&Back: '%1'").arg(getShortString(browseList.at(browsePos-1)->queryText,25)));
+ actBack->setText(i18n("&Back: '%1'").tqarg(getShortString(browseList.at(browsePos-1)->queryText,25)));
actBack->popupMenu()->clear();
int i = browsePos-1;
@@ -593,7 +593,7 @@ void QueryView::updateBrowseActions()
if (browseList.at(browsePos+1)->queryText.isEmpty())
actForward->setText(i18n("&Forward: Information"));
else
- actForward->setText(i18n("&Forward: '%1'").arg(getShortString(browseList.at(browsePos+1)->queryText,25)));
+ actForward->setText(i18n("&Forward: '%1'").tqarg(getShortString(browseList.at(browsePos+1)->queryText,25)));
actForward->popupMenu()->clear();
int i = browsePos+1;
diff --git a/kdict/toplevel.cpp b/kdict/toplevel.cpp
index 496d4d53..fb19461f 100644
--- a/kdict/toplevel.cpp
+++ b/kdict/toplevel.cpp
@@ -14,7 +14,7 @@
------------------------------------------------------------- */
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <kstdaccel.h>
#include <kstdaction.h>
@@ -260,11 +260,11 @@ void TopLevel::define(const TQString &query)
void TopLevel::defineClipboard()
{
kdDebug(5004) << "TopLevel::defineClipboard()" << endl;
- kapp->clipboard()->setSelectionMode(true);
- TQString text = kapp->clipboard()->text();
+ kapp->tqclipboard()->setSelectionMode(true);
+ TQString text = kapp->tqclipboard()->text();
if (text.isEmpty()) {
- kapp->clipboard()->setSelectionMode(false);
- text = kapp->clipboard()->text();
+ kapp->tqclipboard()->setSelectionMode(false);
+ text = kapp->tqclipboard()->text();
}
define(text);
}
@@ -281,11 +281,11 @@ void TopLevel::match(const TQString &query)
void TopLevel::matchClipboard()
{
kdDebug(5004) << "TopLevel::matchClipboard()" << endl;
- kapp->clipboard()->setSelectionMode(true);
- TQString text = kapp->clipboard()->text();
+ kapp->tqclipboard()->setSelectionMode(true);
+ TQString text = kapp->tqclipboard()->text();
if (text.isEmpty()) {
- kapp->clipboard()->setSelectionMode(false);
- text = kapp->clipboard()->text();
+ kapp->tqclipboard()->setSelectionMode(false);
+ text = kapp->tqclipboard()->text();
}
match(text);
}
@@ -394,12 +394,12 @@ void TopLevel::setupStatusBar()
TQString serverInfo;
if (global->authEnabled)
- serverInfo = TQString(" %1@%2:%3 ").arg(getShortString(global->user,50))
- .arg(getShortString(global->server,50))
- .arg(global->port);
+ serverInfo = TQString(" %1@%2:%3 ").tqarg(getShortString(global->user,50))
+ .tqarg(getShortString(global->server,50))
+ .tqarg(global->port);
else
- serverInfo = TQString(" %1:%3 ").arg(getShortString(global->server,50))
- .arg(global->port);
+ serverInfo = TQString(" %1:%3 ").tqarg(getShortString(global->server,50))
+ .tqarg(global->port);
statusBar()->insertItem(serverInfo, 1,3);
statusBar()->setItemAlignment(1,AlignLeft | AlignVCenter);
}
@@ -746,12 +746,12 @@ void TopLevel::optionsChanged()
{
TQString serverInfo;
if (global->authEnabled)
- serverInfo = TQString(" %1@%2:%3 ").arg(getShortString(global->user,50))
- .arg(getShortString(global->server,50))
- .arg(global->port);
+ serverInfo = TQString(" %1@%2:%3 ").tqarg(getShortString(global->user,50))
+ .tqarg(getShortString(global->server,50))
+ .tqarg(global->port);
else
- serverInfo = TQString(" %1:%3 ").arg(getShortString(global->server,50))
- .arg(global->port);
+ serverInfo = TQString(" %1:%3 ").tqarg(getShortString(global->server,50))
+ .tqarg(global->port);
statusBar()->changeItem(serverInfo,1);
interface->serverChanged(); // inform client
queryView->optionsChanged(); // inform html-view
diff --git a/kdict/sets.cpp b/kdict/sets.cpp
index 2d98efc5..fe3f2636 100644
--- a/kdict/sets.cpp
+++ b/kdict/sets.cpp
@@ -14,7 +14,7 @@
------------------------------------------------------------- */
#include <tqpushbutton.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqcombobox.h>
@@ -44,12 +44,12 @@ DbSetsDialog::DbSetsDialog(TQWidget *parent, const char *name)
topLayout->addLayout(subLayout1,0);
w_set = new TQComboBox(true,page);
- w_set->setFixedHeight(w_set->sizeHint().height());
+ w_set->setFixedHeight(w_set->tqsizeHint().height());
w_set->setInsertionPolicy (TQComboBox::NoInsertion);
w_set->insertStringList(sets);
connect(w_set, TQT_SIGNAL(activated(int)),this, TQT_SLOT(activateSet(int)));
TQLabel *l = new TQLabel(w_set, i18n("&Set:"),page);
- l->setMinimumSize(l->sizeHint());
+ l->setMinimumSize(l->tqsizeHint());
subLayout1->addWidget(l,0);
subLayout1->addWidget(w_set,1);
@@ -60,12 +60,12 @@ DbSetsDialog::DbSetsDialog(TQWidget *parent, const char *name)
subLayout1->addWidget(w_save,0);
TQPushButton *btn = new TQPushButton(i18n("&New"),page);
- btn->setMinimumSize(btn->sizeHint());
+ btn->setMinimumSize(btn->tqsizeHint());
connect(btn, TQT_SIGNAL(clicked()),this, TQT_SLOT(newPressed()));
subLayout1->addWidget(btn,0);
w_delete = new TQPushButton(i18n("&Delete"),page);
- w_delete->setMinimumSize(w_delete->sizeHint());
+ w_delete->setMinimumSize(w_delete->tqsizeHint());
connect(w_delete, TQT_SIGNAL(clicked()),this, TQT_SLOT(deletePressed()));
subLayout1->addWidget(w_delete,0);
@@ -83,7 +83,7 @@ DbSetsDialog::DbSetsDialog(TQWidget *parent, const char *name)
connect(w_leftBox, TQT_SIGNAL(selected(int)),this, TQT_SLOT(leftSelected(int)));
connect(w_leftBox, TQT_SIGNAL(highlighted(int)),this, TQT_SLOT(leftHighlighted(int)));
TQLabel *leftLabel = new TQLabel(w_leftBox, i18n("S&elected databases:"),page);
- leftLabel->setMinimumSize(leftLabel->sizeHint());
+ leftLabel->setMinimumSize(leftLabel->tqsizeHint());
subLayout2->addWidget(leftLabel,0,0);
subLayout2->addMultiCellWidget(w_leftBox,1,6,0,0);
@@ -111,7 +111,7 @@ DbSetsDialog::DbSetsDialog(TQWidget *parent, const char *name)
connect(w_rightBox, TQT_SIGNAL(selected(int)),this, TQT_SLOT(rightSelected(int)));
connect(w_rightBox, TQT_SIGNAL(highlighted(int)),this, TQT_SLOT(rightHighlighted(int)));
TQLabel *rightLabel = new TQLabel(w_rightBox, i18n("A&vailable databases:"),page);
- rightLabel->setMinimumSize(rightLabel->sizeHint());
+ rightLabel->setMinimumSize(rightLabel->tqsizeHint());
subLayout2->addWidget(rightLabel,0,2);
subLayout2->addMultiCellWidget(w_rightBox,1,6,2,2);
@@ -264,8 +264,8 @@ void DbSetsDialog::activateSet(int num)
w_set->clearEdit();
w_delete->setEnabled(false);
w_save->setEnabled(false);
- w_rightBox->repaint(true); // Workaround for repaint-bug
- w_leftBox->repaint(true); // Workaround for repaint-bug
+ w_rightBox->tqrepaint(true); // Workaround for tqrepaint-bug
+ w_leftBox->tqrepaint(true); // Workaround for tqrepaint-bug
} else {
w_set->setCurrentItem(num);
for (unsigned int i=0;i<global->serverDatabases.count();i++)
@@ -278,9 +278,9 @@ void DbSetsDialog::activateSet(int num)
w_delete->setEnabled(true);
w_save->setEnabled(true);
if (w_rightBox->count()==0)
- w_rightBox->repaint(true); // Workaround for repaint-bug
+ w_rightBox->tqrepaint(true); // Workaround for tqrepaint-bug
if (w_leftBox->count()==0)
- w_leftBox->repaint(true); // Workaround for repaint-bug
+ w_leftBox->tqrepaint(true); // Workaround for tqrepaint-bug
w_leftBox->clearSelection();
w_leftBox->centerCurrentItem();
w_rightBox->clearSelection();